summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--usr.sbin/rpki-client/as.c8
-rw-r--r--usr.sbin/rpki-client/cert.c6
-rw-r--r--usr.sbin/rpki-client/ip.c6
-rw-r--r--usr.sbin/rpki-client/validate.c4
4 files changed, 12 insertions, 12 deletions
diff --git a/usr.sbin/rpki-client/cert.c b/usr.sbin/rpki-client/cert.c
index b23b5dd6b5b..a8ec8799d29 100644
--- a/usr.sbin/rpki-client/cert.c
+++ b/usr.sbin/rpki-client/cert.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: cert.c,v 1.48 2021/12/26 12:30:11 tb Exp $ */
+/* $OpenBSD: cert.c,v 1.49 2021/12/26 12:32:28 tb Exp $ */
/*
* Copyright (c) 2021 Job Snijders <job@openbsd.org>
* Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
@@ -64,8 +64,8 @@ cert_init_oid(void)
/*
* Append an IP address structure to our list of results.
- * This will also constrain us to having at most one inheritence
- * statement per AFI and also not have overlapping rages (as prohibited
+ * This will also constrain us to having at most one inheritance
+ * statement per AFI and also not have overlapping ranges (as prohibited
* in section 2.2.3.6).
* It does not make sure that ranges can't coalesce, that is, that any
* two ranges abut each other.
diff --git a/usr.sbin/rpki-client/validate.c b/usr.sbin/rpki-client/validate.c
index 6d44b65e5ff..9a9c93232a0 100644
--- a/usr.sbin/rpki-client/validate.c
+++ b/usr.sbin/rpki-client/validate.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: validate.c,v 1.22 2021/11/04 11:32:55 claudio Exp $ */
+/* $OpenBSD: validate.c,v 1.23 2021/12/26 12:32:28 tb Exp $ */
/*
* Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
*
@@ -58,7 +58,7 @@ valid_as(struct auth *a, uint32_t min, uint32_t max)
/*
* Walk up the chain of certificates (really just the last one, but in
- * the case of inheritence, the ones before) making sure that our IP
+ * the case of inheritance, the ones before) making sure that our IP
* prefix is covered in the first non-inheriting specification.
* Returns 1 if covered or 0 if not.
*/
diff --git a/usr.sbin/rpki-client/as.c b/usr.sbin/rpki-client/as.c
index a8f0383305b..88598a6a5de 100644
--- a/usr.sbin/rpki-client/as.c
+++ b/usr.sbin/rpki-client/as.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: as.c,v 1.6 2020/09/12 15:46:48 claudio Exp $ */
+/* $OpenBSD: as.c,v 1.7 2021/12/26 12:32:28 tb Exp $ */
/*
* Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
*
@@ -75,13 +75,13 @@ as_check_overlap(const struct cert_as *a, const char *fn,
{
size_t i;
/* We can have only one inheritence statement. */
if (asz &&
(a->type == CERT_AS_INHERIT || as[0].type == CERT_AS_INHERIT)) {
warnx("%s: RFC 3779 section 3.2.3.3: "
- "cannot have inheritence and multiple ASnum or "
- "multiple inheritence", fn);
+ "cannot have inheritance and multiple ASnum or "
+ "multiple inheritance", fn);
return 0;
}
@@ -75,13 +75,13 @@ as_check_overlap(const struct cert_as *a, const char *fn,
{
size_t i;
- /* We can have only one inheritence statement. */
+ /* We can have only one inheritance statement. */
if (asz &&
(a->type == CERT_AS_INHERIT || as[0].type == CERT_AS_INHERIT)) {
diff --git a/usr.sbin/rpki-client/ip.c b/usr.sbin/rpki-client/ip.c
index 05b072ab75e..8cbcf92a595 100644
--- a/usr.sbin/rpki-client/ip.c
+++ b/usr.sbin/rpki-client/ip.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ip.c,v 1.20 2021/11/10 09:15:29 claudio Exp $ */
+/* $OpenBSD: ip.c,v 1.21 2021/12/26 12:32:28 tb Exp $ */
/*
* Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
*
@@ -129,7 +129,7 @@ ip_addr_check_overlap(const struct cert_ip *ip, const char *fn,
has_v6 = 1;
}
/* Disallow multiple inheritence per type. */
if ((inherit_v4 && ip->afi == AFI_IPV4) ||
(inherit_v6 && ip->afi == AFI_IPV6) ||
@@ -138,7 +138,7 @@ ip_addr_check_overlap(const struct cert_ip *ip, const char *fn,
(has_v6 && ip->afi == AFI_IPV6 &&
ip->type == CERT_IP_INHERIT)) {
warnx("%s: RFC 3779 section 2.2.3.5: "
- "cannot have multiple inheritence or inheritence and "
+ "cannot have multiple inheritance or inheritance and "
"addresses of the same class", fn);
return 0;
}
@@ -129,7 +129,7 @@ ip_addr_check_overlap(const struct cert_ip *ip, const char *fn,
has_v6 = 1;
}
- /* Disallow multiple inheritence per type. */
+ /* Disallow multiple inheritance per type. */
if ((inherit_v4 && ip->afi == AFI_IPV4) ||
(inherit_v6 && ip->afi == AFI_IPV6) ||